@@ -27,9 +27,11 @@ from paperwork.frontend.jobs import Job, JobFactory, JobScheduler, JobFactoryPro
 from paperwork.backend.img.doc import ImgDoc
 from paperwork.backend.img.page import ImgPage
 from paperwork.util import load_uifile
+from paperwork.util import maximize_scan_area
 from paperwork.util import popup_no_scanner_found
 from paperwork.util import set_scanner_opt
 
+
 _ = gettext.gettext
 logger = logging.getLogger(__name__)
 
@@ -164,8 +166,8 @@ class JobFactoryDocScan(JobFactory):
 
     def make_tail(self):
         job = JobSignalEmitter(self, next(self.id_generator))
-        job.connect('signal', 
-                    lambda job: GObject.idle_add(
+        job.connect('signal',
+                    lambda job: GLib.idle_add(
                         self.__multiscan_win.on_global_scan_end_cb))
         return job
 
@@ -296,6 +298,7 @@ class ActionScan(SimpleAction):
             except (KeyError, pyinsane.SaneException), exc:
                 logger.error("Warning: Unable to set scanner source to 'Auto': %s"
                        % exc)
+            maximize_scan_area(scanner)
             try:
                 scan_src = scanner.scan(multiple=True)
             except Exception:
