@@ -39,6 +39,8 @@ from paperwork.frontend.jobs import Job, JobFactory, JobScheduler, JobFactoryPro
 from paperwork.util import image2pixbuf
 from paperwork.util import load_uifile
 from paperwork.util import set_scanner_opt
+from paperwork.util import maximize_scan_area
+
 
 _ = gettext.gettext
 logger = logging.getLogger(__name__)
@@ -160,15 +162,18 @@ class JobResolutionFinder(Job):
             device = pyinsane.Scanner(name=self.__devid)
             sys.stdout.flush()
             resolutions = device.options['resolution'].constraint
-            logger.info("Resolutions found: %s" % resolutions)
+            logger.info("Resolutions found: %s" % str(resolutions))
             sys.stdout.flush()
             # Sometimes sane return the resolutions as a integer array,
             # sometimes as a range (-> tuple). So if it is a range, we turn
             # it into an array
             if isinstance(resolutions, tuple):
+                interval = resolutions[2]
+                if interval < 50:
+                    interval = 50
                 res_array = []
                 for res in range(resolutions[0], resolutions[1] + 1,
-                                 resolutions[2]):
+                                 interval):
                     res_array.append(res)
                 resolutions = res_array
 
@@ -274,7 +279,7 @@ class JobCalibrationScan(Job):
             logger.info("Scanner mode set to 'Gray'")
         else:
             logger.warn("WARNING: Unable to set scanner mode ! May be 'Lineart'")
-
+        maximize_scan_area(dev)
         scan_inst = dev.scan(multiple=False)
         try:
             while True:
